SVC class

Inheritance

Constructors

SVC(List supportVectors, List dualCoef, List intercept, List nSupport, List<int> classes, String kernel, double gamma, double coef0, int degree)
To manually instantiate the SVC. The parameters are lifted directly from scikit-learn. See the attributes here: https://scikit-learn.org/stable/modules/generated/sklearn.svm.SVC.html
SVC.fromMap(Map params)
factory

Properties

classes ↔ List<int>
getter/setter pair
coef0 ↔ double
getter/setter pair
degree ↔ int
getter/setter pair
dualCoef ↔ List
getter/setter pair
gamma ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intercept ↔ List
getter/setter pair
kernel ↔ String
getter/setter pair
nSupport ↔ List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportVectors ↔ List
getter/setter pair

Methods

fromURL(String url) → dynamic
Override in all classes extending Classifier. Load a model from a URL using an HTTP request @TODO
inherited
linear(List<double> X) → List<double>
Linear kernel.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
poly(List<double> X) → List<double>
Polynomial kernel.
predict(List<double> X) → int
Implementation of sklearn.svm.SVC.predict.
override
rbf(List<double> X) → List<double>
RBF kernel.
sigmoid(List<double> X) → List<double>
Sigmoid kernel.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited